@@ -27,15 +27,21 @@ MemoryMap::MemoryMap(const string &path, interprocess::file_mapping *file, inter
     _start = (char*)_region->get_address();
 }
 
+MemoryMap::~MemoryMap()
+{
+    delete _region;
+    delete _file;
+    _region = NULL;
+    _file = NULL;
+}
+
 void MemoryMap::check() const
 {
     char match[] = "jamovi";
     if (memcmp(_start, match, 6) != 0)
         throw runtime_error("Corrupt memory segment");
     char major = _start[6];
-    // char minor = _start[7];
+    char minor = _start[7];
     if (major > MM_VERSION_MAJOR)
         throw runtime_error("Memory segment version is too new");
-    else if (major < MM_VERSION_MAJOR)
-        throw runtime_error("Memory segment version is too old");
 }
